@@ -1,4 +1,11 @@
-var _     = require('lodash'),
+/*
+ * code-forensics
+ * Copyright (C) 2016-2018 Silvio Montanari
+ * Distributed under the GNU General Public License v3.0
+ * see http://www.gnu.org/licenses/gpl.html
+ */
+
+ var _     = require('lodash'),
     utils = require('../utils');
 
 module.exports = function() {
@@ -9,10 +16,10 @@ module.exports = function() {
   this.getConfiguration = function() {
     return {
       maxConcurrency: _.isInteger(maxParallel) ? maxParallel : undefined,
-      debugMode: _.isUndefined(process.env.COMMAND_DEBUG) ? undefined : true,
-      logEnabled: _.isUndefined(process.env.LOG_DISABLED) ? undefined : false,
+      debugMode: !_.isUndefined(process.env.COMMAND_DEBUG),
+      logEnabled: _.isUndefined(process.env.LOG_DISABLED),
       serverPort: _.isInteger(serverPort) ? serverPort : undefined,
-      codeMaat: { options: _.isString(codeMaatOptions) ? utils.arrays.arrayPairsToObject(codeMaatOptions.split(' ')) : undefined }
+      codeMaat: { options: _.isString(codeMaatOptions) ? utils.arrays.arrayPairsToObject(codeMaatOptions.split(' ')) : {} }
     };
   };
 };
