@@ -1,6 +1,6 @@
 /*
  * code-forensics
- * Copyright (C) 2016-2017 Silvio Montanari
+ * Copyright (C) 2016-2018 Silvio Montanari
  * Distributed under the GNU General Public License v3.0
  * see http://www.gnu.org/licenses/gpl.html
  */
@@ -31,8 +31,11 @@ module.exports = function(options) {
     .padding(2)
     .size([options.diameter, options.diameter]);
 
-  this.toSeries = Bluebird.method(function(dataTree) {
-    var rootNode = d3.hierarchy(dataTree);
+  this.toSeries = Bluebird.method(function(data) {
+    if (_.isEmpty(data.children)) {
+      return null;
+    }
+    var rootNode = d3.hierarchy(data);
     rootNode.sum(function(node) {
       return _.ceil(node[options.valueProperty]);
     });
