@@ -1,6 +1,6 @@
 /*
  * code-forensics
- * Copyright (C) 2016-2017 Silvio Montanari
+ * Copyright (C) 2016-2018 Silvio Montanari
  * Distributed under the GNU General Public License v3.0
  * see http://www.gnu.org/licenses/gpl.html
  */
@@ -18,7 +18,7 @@ var ReportInfoModel = function(manifest) {
   this.time = new Date(manifest.time).toLocaleString(localeDetection(), { hour12: false });
 
   this.parameters = _.concat(
-    [{ name: 'dateRange', value: manifest.dateRange.split('_').join(' - ') }],
+    [{ name: 'time period', value: manifest.dateRange.split('_').join(' - ') }],
     _.map(manifest.parameters, function(value, key) {
       return { name: key, value: value };
     })
