@@ -1,6 +1,6 @@
 /*
  * code-forensics
- * Copyright (C) 2016-2017 Silvio Montanari
+ * Copyright (C) 2016-2018 Silvio Montanari
  * Distributed under the GNU General Public License v3.0
  * see http://www.gnu.org/licenses/gpl.html
  */
@@ -10,6 +10,7 @@ var d3 = require('d3'),
 
 var DiagramModel      = require('../diagrams/line_chart/zoomable_diagram_model.js'),
     ZoomBrushHandler  = require('../diagrams/line_chart/zoom_brush_handler.js'),
+    ClipboardHandler  = require('../diagrams/line_chart/clipboard_handler.js'),
     SeriesGroup       = require('../models/series_group_model.js'),
     ColorScaleFactory = require('../utils/color_scale_factory.js'),
     localeDetection   = require('../utils/locale_detection.js');
@@ -37,7 +38,14 @@ module.exports = function(manifest) {
           viewTemplates: ['elementInfo2TooltipTemplate'],
           diagram: {
             Model: DiagramModel,
-            graphHandlers: [new ZoomBrushHandler({ zoomWidth: 820 })],
+            graphHandlers: [
+              new ZoomBrushHandler({ zoomWidth: 820 }),
+              new ClipboardHandler({
+                seriesName: 'Complexity Trend',
+                text: _.property('revision'),
+                message: 'Revision copied to clipboard'
+              })
+            ],
             configuration: {
               plotName: cfg.diagramName,
               style: {
