@@ -1,12 +1,11 @@
 /*
  * code-forensics
- * Copyright (C) 2016-2017 Silvio Montanari
+ * Copyright (C) 2016-2018 Silvio Montanari
  * Distributed under the GNU General Public License v3.0
  * see http://www.gnu.org/licenses/gpl.html
  */
 
-var _  = require('lodash'),
-    d3 = require('d3');
+var _  = require('lodash');
 
 var Model             = require('../diagrams/word_cloud/diagram_model.js'),
     LayoutAdapter     = require('../diagrams/word_cloud/cloud_layout_adapter.js'),
@@ -42,9 +41,7 @@ module.exports = function(manifest) {
                 height: 650,
                 minFontSize: 7
               },
-              colorScaleFactory: function() {
-                return ColorScaleFactory.defaultOrdinal(null, d3.schemeCategory20);
-              }
+              colorScaleFactory: ColorScaleFactory.defaultOrdinal
             },
             controls: {
               filters: {
